==> sodium-0.2.0.tar.gz: lib/src/ffi/sodium_ffi_init.dart <==
import 'dart:ffi';

import '../api/sodium.dart';
import '../api/sodium_exception.dart';
import 'api/sodium_ffi.dart';
import 'bindings/libsodium.ffi.dart';

/// Static class to obtain a [Sodium] instance.
///
/// **Important:** This API is is different depending on whether it is used from
/// the VM or in transpiled JavaScript Code. See the specific implementations
/// for more details.
abstract class SodiumInit {
  const SodiumInit._(); // coverage:ignore-line

  // coverage:ignore-start
  /// Creates a [Sodium] instance for the loaded libsodium.
  ///
  /// The [libsodium] parameter must be a loaded
  /// `[lib]sodium.[so|dll|dylib|a|lib|js]`- depending on your platform. Please
  /// refer to the README for more details on loading the library.
  static Future<Sodium> init(DynamicLibrary libsodium) =>
      initFromSodiumFFI(LibSodiumFFI(libsodium));
  // coverage:ignore-end

  /// Creates a [Sodium] instance for the loaded libsodium as [LibSodiumFFI].
  ///
  /// Helper function that you can use if you can't provide a [DynamicLibrary]
  /// for loading libsodium. Instead, you can pass the [LibSodiumFFI] native
  /// interface, which is the raw dart interface to access the C library.
  ///
  /// Please note that [LibSodiumFFI] is not documented, as it is an auto
  /// generated binding, which simply mimics the C interface in dart, as
  /// required by [dart:ffi].
  static Future<Sodium> initFromSodiumFFI(LibSodiumFFI sodium) {
    final result = sodium.sodium_init();
    SodiumException.checkSucceededInt(result);
    return Future.value(SodiumFFI(sodium));
  }
}

==> sodium-1.1.0.tar.gz: lib/src/ffi/sodium_ffi_init.dart <==
import 'dart:ffi';

import '../api/sodium.dart';
import '../api/sodium_exception.dart';
import 'api/sodium_ffi.dart';
import 'bindings/libsodium.ffi.dart';

/// Static class to obtain a [Sodium] instance.
///
/// **Important:** This API is is different depending on whether it is used from
/// the VM or in transpiled JavaScript Code. See the specific implementations
/// for more details.
abstract class SodiumInit {
  const SodiumInit._(); // coverage:ignore-line

  // coverage:ignore-start
  /// Creates a [Sodium] instance for the loaded libsodium.
  ///
  /// The [libsodium] parameter must be a loaded
  /// `[lib]sodium.[so|dll|dylib|a|lib|js]`- depending on your platform. Please
  /// refer to the README for more details on loading the library.
  ///
  /// By default, the native library automatically get initialized. If you do
  /// not want to initialize it, set [initNative] to false. This can be useful
  /// if you need multiple instances of [Sodium].
  static Future<Sodium> init(
    DynamicLibrary libsodium, {
    bool initNative = true,
  }) =>
      initFromSodiumFFI(LibSodiumFFI(libsodium), initNative: initNative);
  // coverage:ignore-end

  /// Creates a [Sodium] instance for the loaded libsodium as [LibSodiumFFI].
  ///
  /// Helper function that you can use if you can't provide a [DynamicLibrary]
  /// for loading libsodium. Instead, you can pass the [LibSodiumFFI] native
  /// interface, which is the raw dart interface to access the C library.
  ///
  /// Please note that [LibSodiumFFI] is not documented, as it is an auto
  /// generated binding, which simply mimics the C interface in dart, as
  /// required by [dart:ffi].
  ///
  /// By default, the native library automatically get initialized. If you do
  /// not want to initialize it, set [initNative] to false. This can be useful
  /// if you need multiple instances of [Sodium].
  static Future<Sodium> initFromSodiumFFI(
    LibSodiumFFI sodium, {
    bool initNative = true,
  }) {
    if (initNative) {
      final result = sodium.sodium_init();
      SodiumException.checkSucceededInt(result);
    }
    return Future.value(SodiumFFI(sodium));
  }
}
